@@ -7,7 +7,7 @@ from collections import Counter
 from PIL import Image
 
 
-def split(im, rows, cols, image_path, should_cleanup):
+def split(im, rows, cols, image_path, should_cleanup, output_dir=None):
     im_width, im_height = im.size
     row_width = int(im_width / rows)
     row_height = int(im_height / cols)
@@ -19,6 +19,10 @@ def split(im, rows, cols, image_path, should_cleanup):
             outp = im.crop(box)
             name, ext = os.path.splitext(image_path)
             outp_path = name + "_" + str(n) + ext
+            if output_dir != None:
+                if not os.path.exists(output_dir):
+                    os.makedirs(output_dir)
+                outp_path = os.path.join(output_dir, outp_path)
             print("Exporting image tile: " + outp_path)
             outp.save(outp_path)
             n += 1
@@ -43,7 +47,7 @@ def reverse_split(paths_to_merge, rows, cols, image_path, should_cleanup):
     new_width = image1.size[0] * cols
     new_height = image1.size[1] * rows
     print(paths_to_merge)
-    new_image = Image.new('RGB', (new_width, new_height), (250, 250, 250))
+    new_image = Image.new(image1.mode, (new_width, new_height))
     print("Merging image tiles with the following layout:", end=" ")
     for i in range(0, rows):
         print("\n")
@@ -56,7 +60,6 @@ def reverse_split(paths_to_merge, rows, cols, image_path, should_cleanup):
             new_image.paste(image, (j * image.size[0], i * image.size[1]))
     print("Saving merged image: " + image_path)
     new_image.save(image_path)
-    new_image.show()
     if should_cleanup:
         for p in paths_to_merge:
             print("Cleaning up: " + p)
@@ -97,8 +100,15 @@ def main():
                         help="Reverse the splitting process, i.e. merge multiple tiles of an image into one.")
     parser.add_argument("--cleanup", action="store_true",
                         help="After splitting or merging, delete the original image/images.")
+    parser.add_argument("--load-large-images", action="store_true",
+                        help="Ignore the PIL decompression bomb protection and load all large files.")
+    parser.add_argument("--output-dir", type=str,
+                        help="Set the output directory for image tiles (e.g. 'outp/images'). Defaults to current working directory.")
+
     args = parser.parse_args()
     image_path = args.image_path[0]
+    if args.load_large_images:
+        Image.MAX_IMAGE_PIXELS = None
     if args.reverse:
         print(
             "Reverse mode selected! Will try to merge multiple tiles of an image into one.")
@@ -108,7 +118,7 @@ def main():
         # followed by "_" and a number, and with the same file extension.
         expr = re.compile(r"^" + start_name + "_\d+" + ext + "$")
         paths_to_merge = sorted([f for f in os.listdir(
-            os.getcwd()) if re.match(expr, f)])
+            os.getcwd()) if re.match(expr, f)], key=lambda x: int(x.split("_")[-1].split(".")[0]))
         reverse_split(paths_to_merge, args.rows,
                       args.cols, image_path, args.cleanup)
     else:
@@ -126,11 +136,13 @@ def main():
                 im_r.paste(im, (0, offset))
             else:
                 im_r.paste(im, (offset, 0))
-            split(im_r, args.rows, args.cols, image_path, args.cleanup)
+            split(im_r, args.rows, args.cols, image_path,
+                  args.cleanup, output_dir=args.output_dir)
             print("Exporting resized image...")
             im_r.save(image_path + "_squared.png")
         else:
-            split(im, args.rows, args.cols, image_path, args.cleanup)
+            split(im, args.rows, args.cols, image_path,
+                  args.cleanup, output_dir=args.output_dir)
     print("Done!")
 
 
